@@ -3,6 +3,8 @@ import asyncio
 import aiohttp
 import collections.abc
 
+ON = "ON"
+OFF = "OFF"
 
 def update(d, u):
     for k, v in u.items():
@@ -20,8 +22,7 @@ class ApiError(Exception):
 class advantage_air:
     """AdvantageAir Connection"""
 
-    def __init__(self, ip, port=2025, session=None, retry=5):
-
+    def __init__(self, ip: str, port: int=2025, session: aiohttp.ClientSession=None, retry: int=5):
         if session is None:
             session = aiohttp.ClientSession()
 
@@ -30,11 +31,11 @@ class advantage_air:
         self.session = session
         self.retry = retry
 
-        self.aircon = self.advantage_air_endpoint(ip, port, session, retry, "setAircon")
-        self.lights = self.advantage_air_endpoint(ip, port, session, retry, "setLights")
-        self.things = self.advantage_air_endpoint(ip, port, session, retry, "setThings")
+        self.aircon = self._aircon(ip, port, session, retry)
+        self.lights = self._lights(ip, port, session, retry)
+        self.things = self._things(ip, port, session, retry)
 
-    async def async_get(self, retry=None):
+    async def async_get(self, retry:int =None):
         retry = retry or self.retry
         data = {}
         count = 0
@@ -71,17 +72,16 @@ class advantage_air:
             f"No valid response after {count} failed attempt{['','s'][count>1]}. Last error was: {error}"
         )
 
-    class advantage_air_endpoint:
-        def __init__(self, ip, port, session, retry, endpoint):
+    class _endpoint:
+        def __init__(self, ip, port, session, retry) -> None:
             self.ip = ip
             self.port = port
             self.session = session
             self.retry = retry
-            self.endpoint = endpoint
             self.changes = {}
             self.lock = asyncio.Lock()
 
-        async def async_set(self, change):
+        async def async_update(self, change: dict[str, any]) -> bool:
             """Merge changes with queue and send when possible, returning True when done"""
 
             self.changes = update(self.changes, change)
@@ -119,3 +119,47 @@ class advantage_air:
                     except SyntaxError as err:
                         raise ApiError("Invalid response")
             return True
+
+    class _aircon(_endpoint):
+        """Aircon endpoint"""
+
+        endpoint = "setAircon"
+
+        async def async_update_ac(self, ac: str, body: dict) -> bool:
+            """Update an aircon"""
+            return await self.async_update({ac: {"info": body}})
+
+        async def async_update_zone(self, ac: str, zone: str, body: dict) -> bool:
+            """Update a zone"""
+            return await self.async_update({ac: {"zones": {zone: body}}})
+
+    class _lights(_endpoint):
+        """Lights endpoint"""
+
+        endpoint = "setLights"
+
+        async def async_update_state(self, id: str, state: str|bool) -> bool:
+            """Update a lights state"""
+            if state == True:
+                state = ON
+            elif state == False:
+                state = OFF
+            return await self.async_update({id: {"id": id, "state": state}})
+
+        async def async_update_value(self, id: str, value: int) -> bool:
+            """Update a lights state and value"""
+            return await self.async_update({id: {"id": id, "state": (ON if value > 0 else OFF), "value": value}})
+
+    class _things(_endpoint):
+        """Things endpoint"""
+
+        endpoint = "setThings"
+
+        async def async_update_value(self, id: str, value: int|bool) -> bool:
+            """Update a things state and value"""
+            if value == True:
+                value = 100
+            elif value == False:
+                value = 0
+                
+            return await self.async_update({id: {"id": id, "value": value}})
